StructuredNestedDict / sndict
=============================
``StructuredNestedDict``/``sndict`` s are heavy-weight data structures hierarchical of ``dict`` s. Unlike the light-weight ``ndict``, ``sndict`` transforms all underlying ``dict`` s to ``sndict`` s and enforces a fixed dictionary depth internally.

In turn, these constraints allow for more powerful operations to be performed across the different levels of hierarchy.

.. autoclass:: sndict.structurednesteddict.StructuredNestedDict
    :members:
